@@ -67,7 +67,9 @@ def main(
     try:
         import pyem
     except ModuleNotFoundError:
-        print('You need to install pyem for cs2star to work: https://github.com/asarnow/pyem')
+        print('You need to install pyem for cs2star to work:')
+        print('  pip install git+https://github.com/brisvag/pyem.git')
+        sys.exit(1)
 
     from .job_parser import find_cs_files
 
@@ -111,6 +113,9 @@ def main(
         print(Panel(log))
         sys.exit()
     else:
+        # make dest dirs
+        for d in to_create:
+            d.mkdir(parents=True, exist_ok=True)
         with open(dest_dir / 'cs2star.log', 'w+') as logfile:
             logfile.write(cleandoc(f'''
                 # this directory was converted from cryosparc with cs2star.py. Command:
@@ -130,9 +135,6 @@ def main(
         else:
             raise ValueError('Number of passthrough files and particle files is incompatible')
 
-    # make dest dirs
-    for d in to_create:
-        d.mkdir(parents=True, exist_ok=True)
     if dest_star.is_file() and overwrite == 0:
         raise click.UsageError('particle file already exists. To overwrite, use -f')
     if dest_star.is_file() and overwrite == 0:
